@@ -1,5 +1,5 @@
 package Util::Medley::Exec;
-$Util::Medley::Exec::VERSION = '0.047';
+$Util::Medley::Exec::VERSION = '0.049';
 use Modern::Perl;
 use Moose;
 use namespace::autoclean;
@@ -23,7 +23,7 @@ Util::Medley::Exec - proxy for cmdline to libs
 
 =head1 VERSION
 
-version 0.047
+version 0.049
 
 =cut
 
@@ -118,6 +118,12 @@ method decryptStr (Str :$str!,
 	say $crypt->decryptStr(%a);
 }
 
+method fileType (Str :$file!) {
+
+    my $util = Util::Medley::File->new;	
+    say $util->fileType($file);
+}
+
 method yamlBeautifyFile (Str :$file!,
                          Int :$sortDepth = 0) {
 
