@@ -1,5 +1,5 @@
 package Util::Medley::Spawn;
-$Util::Medley::Spawn::VERSION = '0.047';
+$Util::Medley::Spawn::VERSION = '0.049';
 ###############################################################################
 
 use Modern::Perl;
@@ -18,7 +18,7 @@ Util::Medley::Spawn - utility methods for system commands
 
 =head1 VERSION
 
-version 0.047
+version 0.049
 
 =head1 SYNOPSIS
 
@@ -87,10 +87,16 @@ is 0.
 multi method capture(
 	ArrayRef|Str :$cmd!,
 	ArrayRef|Str :$stdin,
-	        Bool :$wantArrayRef
+	        Bool :$wantArrayRef, 
+	        Bool :$wantArrayRefs # alt
   )
 {
-
+    if (!defined $wantArrayRefs) {
+    	if ($wantArrayRef) {
+            $wantArrayRefs = 1;
+    	}
+    }
+   
 	my $cmdStr;
 	if ( ref($cmd) eq 'ARRAY' ) {
 		$cmdStr = join( ' ', @$cmd );
@@ -119,7 +125,7 @@ multi method capture(
 	chomp $stdout;
 	chomp $stderr;
 
-	if ($wantArrayRef) {
+	if ($wantArrayRefs) {
 		return ( [ split( /\n/, $stdout ) ], [ split( /\n/, $stderr ) ],
 			$exit );
 	}
